RustlsConnectorConfig

Struct RustlsConnectorConfig 

pub struct RustlsConnectorConfig { /* private fields */ }
Reexport rustls-connector’s TlsConnector Configuration helper for RustlsConnector

Implementations

Source

impl RustlsConnectorConfig

pub fn new_with_webpki_root_certs() -> RustlsConnectorConfig

Create a new RustlsConnectorConfig using the webpki-root-certs (requires webpki-root-certs feature enabled)

pub fn new_with_platform_verifier() -> RustlsConnectorConfig

Create a new RustlsConnectorConfig using the rustls-platform-verifier mechanism (requires platform-verifier feature enabled)

pub fn new_with_native_certs() -> Result<RustlsConnectorConfig, Error>

Create a new RustlsConnectorConfig using the system certs (requires native-certs feature enabled)

Errors

Returns an error if we fail to load the native certs.

pub fn add_parsable_certificates<'a>( &mut self, der_certs: Vec<CertificateDer<'static>>, )

Parse the given DER-encoded certificates and add all that can be parsed in a best-effort fashion.

This is because large collections of root certificates often include ancient or syntactically invalid certificates.

pub fn with_webpki_root_certs(self) -> RustlsConnectorConfig

Add certs from webpki-root-certs (requires webpki-root-certs feature enabled)

pub fn with_platform_verifier(self) -> RustlsConnectorConfig

Use the rustls-platform-verifier mechanism (requires platform-verifier feature enabled)

pub fn with_native_certs(self) -> Result<RustlsConnectorConfig, Error>

Add the system certs (requires native-certs feature enabled)

Errors

Returns an error if we fail to load the native certs.

pub fn connector_with_no_client_auth(self) -> Result<RustlsConnector, Error>

Create a new RustlsConnector from this config and no client certificate

Errors

Returns an error if we fail to init our verifier

pub fn connector_with_single_cert( self, cert_chain: Vec<CertificateDer<'static>>, key_der: PrivateKeyDer<'static>, ) -> Result<RustlsConnector, Error>

Create a new RustlsConnector from this config and the given client certificate

cert_chain is a vector of DER-encoded certificates. key_der is a DER-encoded RSA, ECDSA, or Ed25519 private key.

Errors

Returns an error if we fail to init our verifier or if key_der is invalid.